// server_env.hpp
//
// read the server.env file and provide a class to access the variables

#ifndef __SERVER_ENV_HPP
#define __SERVER_ENV_HPP

#include <string>
#include <map>
#include <memory>
#include "utils/envmanager.hpp"
namespace dropshell {

// reads path / server.env and provides a class to access the variables.
// each env file is required to have the following variables:
// SSH_HOST
// SSH_USER
// SSH_PORT
// the following replacements are made in the values:
// ${USER} -> the username of the user running dropshell
class server_env {
    public:
        server_env(const std::string& server_name);
        std::string get_variable(const std::string& name) const;
        const std::map<std::string, std::string>& get_variables() const;

        std::string get_SSH_HOST() const;
        std::string get_SSH_USER() const;
        std::string get_SSH_PORT() const;

        std::string get_DROPSHELL_DIR() const;  

        bool is_valid() const;

// helper functions
    public:
        std::string construct_ssh_cmd() const;
        std::string construct_standard_command_run_cmd(const std::string& service_name, const std::string& command) const;
        bool check_remote_items_exist(const std::vector<std::string>& file_paths) const;
        bool execute_ssh_command(const std::string& command, const std::string& error_msg) const;
        
        static bool execute_local_command(const std::string& command, const std::string& error_msg);
        static bool execute_local_command_and_capture_output(const std::string& command, std::string & output);

        bool check_remote_dir_exists(const std::string &dir_path) const;
        bool check_remote_file_exists(const std::string& file_path) const;

    private:
        std::string mServer_name;
        std::map<std::string, std::string> variables;
        bool mValid;
        std::unique_ptr<envmanager> m_env_manager;
};

} // namespace dropshell


#endif // __SERVER_ENV_HPP  